.. module:: pymeasure.instruments.tektronix

#########
Tektronix
#########

This section contains specific documentation on the Tektronix instruments that are implemented. If you are interested in an instrument not included, please consider :doc:`adding the instrument </dev/adding_instruments/index>`.

.. toctree::
   :maxdepth: 2

   tds2000
   afg3152c